==> chemistry-opencmis-commons-api-0.3.0-sources.jar: org/apache/chemistry/opencmis/commons/exceptions/CmisNameConstraintViolationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.commons.exceptions;

import java.math.BigInteger;

/**
 * CMIS NameConstraintViolation Exception.
 */
public class CmisNameConstraintViolationException extends CmisBaseException {

    private static final long serialVersionUID = 1L;

    public CmisNameConstraintViolationException() {
        super();
    }

    public CmisNameConstraintViolationException(String message, BigInteger code, Throwable cause) {
        super(message, code, cause);
    }

    public CmisNameConstraintViolationException(String message, String errorContent) {
        super(message, errorContent);
    }

    public CmisNameConstraintViolationException(String message, BigInteger code) {
        super(message, code);
    }

    public CmisNameConstraintViolationException(String message, String errorContent, Throwable cause) {
        super(message, errorContent, cause);
    }

    public CmisNameConstraintViolationException(String message, Throwable cause) {
        super(message, BigInteger.ZERO, cause);
    }

    public CmisNameConstraintViolationException(String message) {
        super(message, BigInteger.ZERO);
    }
}

==> chemistry-opencmis-commons-api-0.10.0-sources.jar: org/apache/chemistry/opencmis/commons/exceptions/CmisNameConstraintViolationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.commons.exceptions;

import java.math.BigInteger;

/**
 * CMIS NameConstraintViolation Exception.
 * <p>
 * Intent: The repository is not able to store the object that the user is
 * creating/updating due to a name constraint violation.
 */
public class CmisNameConstraintViolationException extends CmisBaseException {

    private static final long serialVersionUID = 1L;
    public static final String EXCEPTION_NAME = "nameConstraintViolation";

    public CmisNameConstraintViolationException() {
        super();
    }

    public CmisNameConstraintViolationException(String message, BigInteger code, Throwable cause) {
        super(message, code, cause);
    }

    public CmisNameConstraintViolationException(String message, String errorContent) {
        super(message, errorContent);
    }

    public CmisNameConstraintViolationException(String message, BigInteger code) {
        super(message, code);
    }

    public CmisNameConstraintViolationException(String message, BigInteger code, String errorContent) {
        super(message, code, errorContent);
    }

    public CmisNameConstraintViolationException(String message, String errorContent, Throwable cause) {
        super(message, errorContent, cause);
    }

    public CmisNameConstraintViolationException(String message, Throwable cause) {
        super(message, BigInteger.ZERO, cause);
    }

    public CmisNameConstraintViolationException(String message) {
        super(message, BigInteger.ZERO);
    }

    @Override
    public final String getExceptionName() {
        return EXCEPTION_NAME;
    }
}
